//#####################################################################
// Copyright 2024
// This file is part of PhysBAM whose distribution is governed by the license contained in the accompanying file PHYSBAM_COPYRIGHT.txt.
//#####################################################################
#ifndef __CHONS_SYMBOLIC__
#define __CHONS_SYMBOLIC__
#include <Core/Data_Structures/HASHTABLE.h>
#include <Core/Symbolics/INSTRUCTION.h>
#include <Core/Vectors/VECTOR.h>
#include "CHNS_SYMBOLIC.h"
namespace PhysBAM{

template<class T> class EXECUTABLE_PROGRAM;
namespace NS_PROGRAM_SCALAR{template<class T> class PROGRAM_SCALAR;}

template<class TV>
class CHONS_SYMBOLIC:public CHNS_SYMBOLIC<TV>
{
    typedef typename TV::SCALAR T;
    typedef VECTOR<int,TV::m> IV;
    typedef CHNS_SYMBOLIC<TV> BASE;

    using BASE::inputs;
    using BASE::idx_X;
    using BASE::idx_t;
    using BASE::idx_dt;
    using BASE::idx_lambda;
    using BASE::idx_eta;
    using BASE::idx_M;
    using BASE::idx_rho0;
    using BASE::idx_rho1;
    using BASE::idx_mu0;
    using BASE::idx_mu1;
    using BASE::idx_g;
    using BASE::idx_second_order;
    using BASE::idx_t2;
    using BASE::idx_t0;
    using BASE::idx_sigma;
    using BASE::idx_m;
    using BASE::idx_s;
    using BASE::idx_kg;
    using BASE::idx_pressure_scale;
    using BASE::idx_speed_scale;
    MEM_IN idx_r;
    MEM_IN idx_b;
    MEM_IN idx_Fscale;
    using BASE::input_size;

    using BASE::idx_u;
    using BASE::idx_p;
    using BASE::idx_gamma;

    using BASE::lambda;
    using BASE::eta;
    using BASE::M;
    using BASE::rho0;
    using BASE::rho1;
    using BASE::mu0;
    using BASE::mu1;
    using BASE::gravity;
    using BASE::second_order;
    using BASE::sigma;
    using BASE::distance_scale;
    using BASE::time_scale;
    using BASE::mass_scale;
    using BASE::speed_scale;
    using BASE::pressure_scale;

    using BASE::t_map;
    using BASE::tv_map;
    
    void Add(const std::string& name,const NS_PROGRAM_SCALAR::PROGRAM_SCALAR<T>& ps);
    template<int d> void Add(const std::string& name,const VECTOR<NS_PROGRAM_SCALAR::PROGRAM_SCALAR<T>,d>& ps);
    // template<int m,int n> void Add(const std::string& name,const MATRIX<NS_PROGRAM_SCALAR::PROGRAM_SCALAR<T>,m,n>& ps);

  public:
    T r=0.01;
    T b=0.01;
    T Fscale=0.25;
    CHONS_SYMBOLIC(const std::string& analytic_solution,bool linearize,bool use_st,int st_type,bool use_adv,bool fix_momen,T r_in,T b_in,T F_scale,bool alt_F,bool use_b);
    ~CHONS_SYMBOLIC();
    
    void Set_Step(T time, T dt);
    
};
}
#endif
