#!/bin/bash
#===================================================================
# June 2023 -Mehrnaz Ayazi
# Streamline figure of advection test
# The cases are documented in examples/periodic_advection_test.sh
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

(
function f()
{
  echo "Creating advection test streamline figures..."

    #output directory
    ob=$1
    #list of directories
    dir=$2
    # number of streamlines
    n=$3
    #dimension
    D=2
    dt=0.00078125
    T=''
    echo "starting ..."
    echo "Running $ob..."
    cmd="$basedir/advection_test -fig $fig -ob $ob -n $n -i $dir -dt $dt"
    cmd="$cmd || exit 1"
    echo $cmd
    $cmd
    sl=$fig/tex/"streamline_"$ob.tex
    echo cp $sc/advection_test.tex $sl
    cp $sc/advection_test.tex $sl
    for (( i=0; i<=$n; i++ ));
    do
        filename0="$fig/txt/advection_surface0_"$dir"_"$ob.txt
        filename1="$fig/txt/advection_surface1_"$dir"_"$ob.txt
        echo $filename0
    done
    sed -i -e "s@YY@y@g" -e "s@XX@x@g" -e "s@MMM@""@g" -e "s@QQ@streamline@g" -e "s@DDD@$dir@g" -e "s@FFF@$ob.txt@g" -e "s@SSS0@$filename0@g" -e "s@SSS1@$filename1@g" -e "s@YMAX@1@g" -e "s@YMIN@0@g" -e "s@TTT@$T@" -e "s@NNN@$D@" -e "s@FIG@$fig@" $sl

    pdflatex -halt-on-error -output-directory=$fig/pdfs $fig/tex/"streamline_"$ob.tex
#    cp $fig/pdfs/"streamline_"$ob.pdf $fig
    echo "done creating advection test streamline figures..."
}

function g() # advection table
{
  echo "Creating Advection Test Table..."
    mode=$1 #with or without surface tension
    input_dir=$2
    frame=$3
    Output_base=$4

    cmd="$basedir/periodic_advection_error -mode $mode -fig $fig"
    for dir in $input_dir ; do
        cmd="$cmd -dir $dir -frame $3"
    done
    cmd="$cmd || exit 1"
    echo $cmd
    $cmd

#    cp $fig/tex/advection_table_"$mode".tex $fig
#    cp $fig/tex/advection_table_"$mode".tex $fig
#    cp $fig/tex/advection_table_"$mode".tex $fig/tex
    echo "Done creating Advection Test Table"
}
echo "starting the advection test figure script ..."
#Computes velocity errors
g "base" "periodic_advection_0 periodic_advection_1 periodic_advection_2 periodic_advection_3" 64
g "st" "periodic_advection_4 periodic_advection_5 periodic_advection_6 periodic_advection_7" 64

f case0 "periodic_advection_0" 9
f case1 "periodic_advection_1" 9
f case2 "periodic_advection_2" 9
f case3 "periodic_advection_3" 9
f case4 "periodic_advection_4" 9
f case5 "periodic_advection_5" 9
f case6 "periodic_advection_6" 9
f case7 "periodic_advection_7" 9

wait
)
