#!/bin/bash
#===================================================================
# June 2023 -Mehrnaz Ayazi
# Creates surface, circularity ,center of mass and rising velocity figures
# It also creates the data needed for air bubble table script. Must run before runnig the table script
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

r=${1:-0}
basedir=$PROJ/chns_project

function prepare_data()
{
    #name of figure
    ob=$1
    #list of directories
    input_dir=$2
    cmd="$basedir/air_bubble_data -fig $fig"
    for dir in $input_dir ; do
        cmd="$cmd -i $dir"
    done
    cmd="$cmd -ch_min $r || exit 1"
    echo $cmd
    $cmd
}
function generate_pdf()
{
    #name of figure
    ob=$1
    #list of directories
    input_dir=$2
    #dimension
    D=2
    #caption of plot
    Xcaption=$3
    Ycaption=$4
    #type of plot (surface, circularity,velocity,COM)
    TITLE=$5
    YMIN=$6
    YMAX=$7
    XMIN=$8
    XMAX=$9
    # Mode. is it cycle or curve
    M=${10}
    # set this one if you want to make the this a figure of all cases
    all_case=${11:0}
    T=''

    if [ $all_case == 0 ]
    then
        tex_file=$fig/tex/$TITLE"_"$ob.tex
        pdf_file=$fig/pdfs/$TITLE"_"$ob.pdf
        cp $sc/air_bubble_graph.tex $tex_file
    else
        tex_file=$fig/tex/$TITLE"_all".tex
        pdf_file=$fig/pdfs/$TITLE"_all".pdf
        cp $sc/air_bubble_graph_all.tex $tex_file
    fi

    sed -i -e "s@FIG@$fig@g" -e "s/YCAPTION/$Ycaption/g" -e "s/XCAPTION/$Xcaption/g" -e "s/MMM/$M/g" -e "s/QQ/$TITLE/g" -e "s/YMAX/$YMAX/g" -e "s/YMIN/$YMIN/g" -e "s/XMAX/$XMAX/g" -e "s/XMIN/$XMIN/g" -e "s/TTT/$T/" -e "s/NNN/$D/" $tex_file
    if [ $TITLE == 'surface' ]
    then
        sed -i -e "s/YY/y/g" -e "s/XX/x/g" $tex_file
    else
        sed -i -e "s/YY/$TITLE/g" -e "s/XX/t/g" $tex_file
    fi
    for dir in $input_dir ; do
        filename=$TITLE"_"$dir.txt
        if [ $all_case == 0 ]
        then
            IFS='-' read -a REF_ARRAY <<< $fig/$dir
            REF=${REF_ARRAY[2]}
            sed -i -e "s/REF$REF}/$filename}/g" $tex_file
        else
            IFS='-' read -a CASE <<< $fig/$dir
            CASE=${CASE[1]}
            sed -i -e "s/CASE$CASE/$filename/g" $tex_file
        fi
        
        (pdflatex -halt-on-error -output-directory=$fig/pdfs $tex_file && cp $pdf_file $fig) &
    done
}

# generate figures for each case in air_bubble_test.sh
for CASE in 1 2 3 4 5 6;
do
    ob=rising_air_bubble_"$CASE"
    DIRS="air_bubble-"$CASE"-1 air_bubble-"$CASE"-2 air_bubble-"$CASE"-4 air_bubble-"$CASE"-8 air_bubble-"$CASE"-16"
    prepare_data $ob "$DIRS"
    wait
    (generate_pdf $ob "$DIRS" '$t$' '$\\psi_c$' "circularity" 0.9 1.01 0 1 "" 0)
    (generate_pdf $ob "$DIRS" '$x$' '$y$' "surface" 0.4 1 0.1 0.9 "--cycle" 0)
    (generate_pdf $ob "$DIRS" '$t$' '$y_c$' "COM" 0.48 0.70 0 1 "" 0)
    (generate_pdf $ob "$DIRS" '$t$' '$v_c$' "velocity" 0.0 0.3 0 1 "" 0)
done
wait
# all cases comparison
DIRS_all="air_bubble-1-16 air_bubble-2-16 air_bubble-3-16 air_bubble-4-16 air_bubble-5-16 air_bubble-6-16"
(generate_pdf rising_air_bubble "$DIRS_all" '$t$' '$\\psi_c$' "circularity" 0.9 1.01 0 1 "" 1)
(generate_pdf rising_air_bubble "$DIRS_all" '$x$' '$y$' "surface" 0.4 1 0.1 0.9 "--cycle" 1)
(generate_pdf rising_air_bubble "$DIRS_all" '$t$' '$y_c$' "COM" 0.48 0.70 0 1 "" 1)
(generate_pdf rising_air_bubble "$DIRS_all" '$t$' '$v_c$' "velocity" 0.0 0.3 0 1 "" 1)

wait
