#!/bin/bash
#===================================================================
# June 2023 -Mehrnaz Ayazi
# Fills in the table for air bubble test(Table 8 in consistent paper)
# The cases are documented in examples/air_bubble_test.sh
# cpp file changes the tex file for this script
# To run this script you should have already run sim2fig.sh script
# You need a reference sim for each case. You need to pass the dt of the reference sim and dt of the sim you are creating a reference for
# We need a separate reference file for each resolution because the number of frames are different in each of them
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

r=${1:-0}

(
    function prepare_data() # completely unused?
    {
        #name of figure
        ob=$1
        #list of directories
        input_dir=$2
        cmd="$basedir/air_bubble_data -fig $fig"
        for dir in $input_dir ; do
            cmd="$cmd -i $dir"
        done
        cmd="$cmd -ch_min $r -table || exit 1"
        echo $cmd
        $cmd
    }
    function fill_table()
    {
        ob=$1
        input_dir=$2
        ref_dir=$3
        casenum=$4

        cmd="$basedir/air_bubble_table -fig $fig -ref $ref_dir -case $casenum -tex order_"$ob"_table.tex"
        for dir in $input_dir ; do
            IFS='-' read -a RES <<< $dir
            refine=${RES[2]}
            resx=$(perl -e 'print 16*'$refine)
            cmd="$cmd -i $dir -res $resx"
        done

        cmd="$cmd || exit 1"
        echo $cmd
        $cmd
        # Comment this if you want to see the pdf first
        cp $fig/tex/order"_"$ob"_table".tex $fig
    }

    for CASE in 1 2 3 4 5 6;
    do
        ob=rising_air_bubble_"$CASE"
        DIRS="air_bubble-"$CASE"-1 air_bubble-"$CASE"-2 air_bubble-"$CASE"-4 air_bubble-"$CASE"-8 air_bubble-"$CASE"-16"
        prepare_data $ob "$DIRS"
    done
    wait
    for CASE in 1 2 3 4 5 6; do
        $basedir/air_bubble_data -fig $fig -i air_bubble-"$CASE"-16 -ref -ch_min $r
    done
    wait

    cp $sc/air_bubble_table_temp.tex tex/order_rising_air_bubble_table.tex
    for CASE in 1 2 3 4 5 6;
    do
        fill_table rising_air_bubble "air_bubble-"$CASE"-1 air_bubble-"$CASE"-2 air_bubble-"$CASE"-4 air_bubble-"$CASE"-8" "air_bubble-"$CASE"-16" $CASE
    done
    wait
)
