#!/bin/bash
#===================================================================
# August 2023 -Mehrnaz Ayazi, Jason Goulding
# Creates plots of pressure versus x/y
# Uses the end-state frames of the steady_drop.sh, case 1
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

(
    function f()
    {
        type=$1
        #list of directories
        input_dirs=$2
        #caption of plot
        Xcaption=$3
        Ycaption=$4
        #type of plot (Change in Mass, Change in KE, Change in Momentum X/Y)
        YMIN=$5
        YMAX=$6
        XMIN=$7
        XMAX=$8
        TEX_FILE=$9
        #dimension
        D=2
        
        output_file="$fig/tex/"$TEX_FILE"_"$type".tex"
        cp $sc/$TEX_FILE.tex $output_file
        sed -i -e "s@FIG@$fig@g" -e "s/YY/pressure/g" -e "s/XX/$type/g" -e "s/YCAPTION/$Ycaption/g" -e "s/XCAPTION/$Xcaption/g" -e "s/QQ/$type/g" -e "s/YMAX/$YMAX/g" -e "s/YMIN/$YMIN/g" -e "s/XMAX/$XMAX/g" -e "s/XMIN/$XMIN/g" -e "s/NNN/$D/" $output_file
        
        for dir in $input_dirs ; do
            filename="pressure_"$dir"_"$type".txt"
            # echo "dir=$dir"
            # echo "filename=$filename"
            if [ $dir == 'ideal' ]
            then
                sed -i -e "s/IDEAL/$filename/g" $output_file
            else
                IFS='_-' read -a RES <<< $dir
                CASE=${RES[1]}
                # echo "case=$CASE"
                sed -i -e "s/CASE$CASE/$filename/g" $output_file
            fi
        done
        
        (pdflatex -halt-on-error -output-directory=$fig/pdfs $output_file && cp $fig/pdfs/$TEX_FILE"_"$type.pdf $fig) &
    }

    $basedir/pressure_data -fig $fig -ideal -r 0.2 -sigma 1
    DIRS="ideal"
    for CASE in 1 2 5 8 9;
    do
        d="pressure_"$CASE
        $basedir/pressure_data -fig $fig -dir $d  -frame 25 -left_shift &
        DIRS="$DIRS $d"
    done

    f 'x' "$DIRS" '$x$' '$p$' -1 6 0 1 "pressure_graph_no_g"
    # f 'y' "$DIRS" '$y$' '$p$' 0 6 0 1
    DIRS="ideal"
    for CASE in  3 4 5 6 7;
    do
        d="pressure_"$CASE
        $basedir/pressure_data -fig $fig -dir $d  -frame 25 -left_shift &
        DIRS="$DIRS $d"
    done

    f 'x' "$DIRS" '$x$' '$p$' -1 6 0 1 "pressure_graph"

    wait
)
