#!/bin/bash
#===================================================================
# August 2023 -Mehrnaz Ayazi, Jason Goulding
# Creates mass change, kinetic energy change, and momentum change plots in pdf form
# Run the horizontal_shear.sh script for cases 1-4 before using this script
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

(
    function f()
    {
        type=$1
        #list of directories
        input_dirs=$2
        #caption of plot
        Xcaption=$3
        Ycaption=$4
        #type of plot (Change in Mass, Change in KE, Change in Momentum X/Y)
        YMIN=$5
        YMAX=$6
        XMIN=$7
        XMAX=$8
        #dimension
        D=2
        
        output_file="$fig/tex/shear_graph_"$type".tex"
        cp $sc/shear_graph.tex $output_file
        sed -i -e "s@FIG@$fig@g" -e "s/YY/$type/g" -e "s/XX/t/g" -e "s/YCAPTION/$Ycaption/g" -e "s/XCAPTION/$Xcaption/g" -e "s/QQ/$type/g" -e "s/YMAX/$YMAX/g" -e "s/YMIN/$YMIN/g" -e "s/XMAX/$XMAX/g" -e "s/XMIN/$XMIN/g" -e "s/NNN/$D/" $output_file
        
        for dir in $input_dirs ; do
            filename=$type"_"$dir.txt
            # echo "dir=$dir"
            # echo "filename=$filename"
            IFS='_' read -a RES <<< $dir
            CASE=${RES[2]}
            # echo "case=$CASE"
            sed -i -e "s/CASE$CASE/$filename/g" $output_file
        done
        
        (pdflatex -halt-on-error -output-directory=$fig/pdfs $output_file && cp $fig/pdfs/shear_graph_"$type".pdf $fig) &
    }

    $basedir/shear_data -fig $fig -dir horizontal_shear_1 -dt 0.01 -rho0 1 -rho1 1
    $basedir/shear_data -fig $fig -dir horizontal_shear_2 -dt 0.01 -rho0 1 -rho1 10
    $basedir/shear_data -fig $fig -dir horizontal_shear_3 -dt 0.01 -rho0 1 -rho1 1
    $basedir/shear_data -fig $fig -dir horizontal_shear_4 -dt 0.01 -rho0 1 -rho1 10

    DIRS="horizontal_shear_1 horizontal_shear_2 horizontal_shear_3 horizontal_shear_4"

    f 'masschange' "$DIRS" '$t$' 'Mass\\\\($t$\\\\)-Mass\\\\($t=0$\\\\)' -9e-12 1e-12 0 1
    f 'kechange' "$DIRS" '$t$' '$E_K\(t\)-E_K\(t=0\)$' -0.25 0.05 0 1
    f 'mochangex' "$DIRS" '$t$' 'Momentum-x\\\\($t$\\\\)-Momentum-x\\\\($t=0$\\\\)' -9e-13 3e-13 0 1
    f 'mochangey' "$DIRS" '$t$' 'Momentum-y\\\\($t$\\\\)-Momentum-y\\\\($t=0$\\\\)' -5e-15 5e-15 0 1

    wait
)
