#!/bin/bash
#===================================================================
# June 2023 -Mehrnaz Ayazi
# Creates surface, circularity ,center of mass and rising velocity figures
# It also creates the data needed for air bubble table script. Must run before runnig the table script
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

r=${1:-0}

(
    function prepare_data()
    {
        #name of figure
        ob=$1
        #list of directories
        input_dir=$2
        cmd="$basedir/sim2fig -fig $fig -ob $fig/$ob"
        for dir in $input_dir ; do
            IFS='-' read -a RES <<< $dir
            resx=${RES[2]}
            dt=$(perl -e 'print 0.128/'$resx)
            cmd="$cmd -i $dir -dt $dt -res $resx -ch_min $r"
        done
        cmd="$cmd -table || exit 1"
        echo $cmd
        $cmd
    }
    function generate_pdf()
    {
        #name of figure
        ob=$1
        #list of directories
        input_dir=$2
        #dimension
        D=2
        #caption of plot
        Xcaption=$3
        Ycaption=$4
        #type of plot (surface, circularity,velocity,COM)
        TITLE=$5
        YMIN=$6
        YMAX=$7
        XMIN=$8
        XMAX=$9
        # Mode. is it cycle or curve
        M=${10}
        # set this one if you want to make the this a figure of all cases
        all_case=${11:0}
        T=''


        if [ $all_case == 0 ]
        then
          tex_file=$fig/tex/$TITLE"_"$ob.tex
          pdf_file=$fig/pdfs/$TITLE"_"$ob.pdf
          cp $sc/sim2fig.tex $tex_file
        else
            echo "else statement"
          tex_file=$fig/tex/$TITLE"_all".tex
          pdf_file=$fig/pdfs/$TITLE"_all".pdf
          cp $sc/sim2fig_all.tex $tex_file
        fi

        sed -i -e "s@FIG@$fig@g" -e "s/YCAPTION/$Ycaption/g" -e "s/XCAPTION/$Xcaption/g" -e "s/MMM/$M/g" -e "s/QQ/$TITLE/g" -e "s/YMAX/$YMAX/g" -e "s/YMIN/$YMIN/g" -e "s/XMAX/$XMAX/g" -e "s/XMIN/$XMIN/g" -e "s/TTT/$T/" -e "s/NNN/$D/" $tex_file
        if [ $TITLE == 'surface' ]
        then
            sed -i -e "s/YY/y/g" -e "s/XX/x/g" $tex_file
        else
            sed -i -e "s/YY/$TITLE/g" -e "s/XX/t/g" $tex_file
        fi
        for dir in $input_dir ; do
            if [ $all_case == 0 ]
            then
              filename=$dir"_"$TITLE"_"$ob.txt
              IFS='-' read -a RES <<< $dir
              RES=${RES[2]}
              sed -i -e "s/RES$RES/$filename/g" $tex_file
            else
              IFS='-' read -a CASE <<< $dir
              CASE=${CASE[1]}
              filename=$dir"_"$TITLE"_rising_air_bubble_"$CASE.txt
              sed -i -e "s/CASE$CASE/$filename/g" $tex_file
            fi

            
            (pdflatex -halt-on-error -output-directory=$fig/pdfs $tex_file && cp $pdf_file $fig) &
        done
    }

    # generate figures for each case in $fig/air_bubble_test.sh
    # for CASE in 1 2 3 4 5 6;
    for CASE in 1;
    do
        ob=rising_air_bubble_"$CASE"
        DIRS="$fig/air_bubble-"$CASE"-16 $fig/air_bubble-"$CASE"-32 $fig/air_bubble-"$CASE"-64 $fig/air_bubble-"$CASE"-128 $fig/air_bubble-"$CASE"-256"
        prepare_data $ob "$DIRS"
        wait
        (generate_pdf $ob "$DIRS" '$t$' '$\\psi_c$' "circularity" 0.9 1.01 0 1 "" 0)
        (generate_pdf $ob "$DIRS" '$x$' '$y$' "surface" 0.4 1 0.1 0.9 "--cycle" 0)
        (generate_pdf $ob "$DIRS" '$t$' '$y_c$' "COM" 0.49 0.7 0 1 "" 0)
        (generate_pdf $ob "$DIRS" '$t$' '$v_c$' "velocity" 0.0 0.3 0 1 "" 0)
    done
    wait
    # all cases comparison
    DIRS_all="$fig/air_bubble-1-256 $fig/air_bubble-2-256 $fig/air_bubble-3-256 $fig/air_bubble-4-256 $fig/air_bubble-5-256 $fig/air_bubble-6-256"
#    DIRS_all="$fig/air_bubble-1-128 $fig/air_bubble-2-128 $fig/air_bubble-3-128 $fig/air_bubble-4-128 $fig/air_bubble-5-128 $fig/air_bubble-6-128"
    # (generate_pdf $fig/rising_air_bubble "$DIRS_all" '$t$' '$\\psi_c$' "circularity" 0.9 1.01 0 1 "" 1)
    # (generate_pdf $fig/rising_air_bubble "$DIRS_all" '$x$' '$y$' "surface" 0.4 1 0.1 0.9 "--cycle" 1)
    # (generate_pdf $fig/rising_air_bubble "$DIRS_all" '$t$' '$y_c$' "COM" 0.49 0.7 0 1 "" 1)
    # (generate_pdf $fig/rising_air_bubble "$DIRS_all" '$t$' '$v_c$' "velocity" 0.0 0.3 0 1 "" 1)

    #These lines are just for the table ???
    # for CASE in 1 2 3 4 5 6;
    #     do
    #         f $fig/rising_air_bubble_table "$fig/air_bubble-"$CASE"-16 $fig/air_bubble-"$CASE"-32 $fig/air_bubble-"$CASE"-64 $fig/air_bubble-"$CASE"-128" "\\\\(t\\\\)" "\\\\(\\\\psi_c\\\\)" "circularity" 0.9 1.01 0 1 ""
    #         f $fig/rising_air_bubble_table "$fig/air_bubble-"$CASE"-16 $fig/air_bubble-"$CASE"-32 $fig/air_bubble-"$CASE"-64 $fig/air_bubble-"$CASE"-128" "\\\\(t\\\\)" "\\\\(y_c\\\\)" "COM" 0.49 0.7 0 1 ""
    #         f $fig/rising_air_bubble_table "$fig/air_bubble-"$CASE"-16 $fig/air_bubble-"$CASE"-32 $fig/air_bubble-"$CASE"-64 $fig/air_bubble-"$CASE"-128" "\\\\(t\\\\)" "\\\\(v_c\\\\)" "velocity" 0.0 0.35 0 1 ""
    #     done


    wait
)
