#!/bin/bash
#==============================================================
# June 2023-Mehrnaz Ayazi
#Creates L2-Linf figures for steady drop test
#==============================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

L2scale=${1:-1}
Linfscale=${2:-1}

(
    # This function runs the cpp file to create the text files containing the errors
    function get_data()
    {
        # This name must contain the case number(e.g test_case1)
        ob=$1
        # list of directories
        input_dir=$2
        cmd="$basedir/steady_error -fig $fig -ob $ob"
        echo $cmd
        for dir in $input_dir ; do
            filename=$fig/txt/$dir"_"$U"_"$ob.txt
            IFS='-' read -a RES <<< $fig/txt/$dir
            resx=${RES[1]}
            cmd="$cmd -i $dir -res $resx"
        done

        cmd="$cmd -L2_scale $L2scale -Linf_scale $Linfscale || exit 1"
        echo $cmd
        $cmd
    }
    # This function creates the plots
    function make_plot()
    {
        # This is the name passed to f function without the case number(e.g test)
        ob=$1
        # L2 or Linf
        MODE=$2
        Xcaption=$3
        Ycaption=$4
        C=$5
        XMIN=0
        XMAX=0
        YMIN=0
        YMAX=0
        cp $sc/steady_error.tex $fig/tex/$MODE"_"$ob.tex
        tex_file=$fig/tex/$MODE"_"$ob.tex
        pdf_file=$fig/pdfs/$MODE"_"$ob.pdf
        sed -i -e "s@FIG@$fig@g" -e "s/YY/error/g" -e "s/XX/res/g" -e "s/YCAPTION/$Ycaption/g" -e "s/XCAPTION/$Xcaption/g"  -e "s/YMAX/$YMAX/g" -e "s/YMIN/$YMIN/g" -e "s/XMAX/$XMAX/g" -e "s/XMIN/$XMIN/g" -e "s/CCC/$C/g"  $fig/tex/$MODE"_"$ob.tex
        for CASE in 1 2 3 4 5 6 7; do
            filename=$MODE"_"$ob"_case"$CASE.txt
            sed -i -e "s@FIG@$fig@g" -e "s/CASE$CASE/$filename/g"  $tex_file
        done
        (pdflatex -halt-on-error -output-directory=$fig/pdfs $tex_file && cp $pdf_file $fig)
    }

    #f error_test_case0 "steady_drop_0-16 steady_drop_0-32 steady_drop_0-64  steady_drop_0-128"
    for CASE in 1 2 3 4 5;
    do
        get_data error_test_case"$CASE" "steady_drop_"$CASE"-1 steady_drop_"$CASE"-2 steady_drop_"$CASE"-4  steady_drop_"$CASE"-8 steady_drop_"$CASE"-16"
        get_data error_test_constant_case"$CASE" "steady_drop_"$CASE"_constant-1 steady_drop_"$CASE"_constant-2 steady_drop_"$CASE"_constant-4  steady_drop_"$CASE"_constant-8 steady_drop_"$CASE"_constant-16"
        # f error_test_case"$CASE" "steady_drop_"$CASE"-1 steady_drop_"$CASE"-2 steady_drop_"$CASE"-4  steady_drop_"$CASE"-8"
    done

    if [ "$L2scale" != "1" ]
    then
        L2scalename="\\\\num\{$L2scale\}"
    fi

    if [ "$Linfscale" != "1" ]
    then
        Linfscalename="\\\\num\{$Linfscale\}"
    fi
    
    make_plot error_test "L2" "N" "L_2" "10^{-6}"
    make_plot error_test "L2" "N" "L_2" "$L2scalename"
    make_plot error_test "Linf" "N" "L_\\\\infty" "$Linfscalename"
    make_plot error_test_constant "L2" "N" "L_2" "$L2scalename"
    make_plot error_test_constant "Linf" "N" "L_\\\\infty" "$Linfscalename"
    wait

)
