#!/bin/bash
#===================================================================
# June 2023 -Mehrnaz Ayazi
#Takes snapshots of the sim
#Might need to change the color in tex file for different figures
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

function f()
{

    ob=$1
    #list of directories
    #Only pass one output directory
    input_dir=$2
    #dimension
    D=2
    Xcaption=$3
    Ycaption=$4
    YMIN=$5
    YMAX=$6
    XMIN=$7
    XMAX=$8
    XLEN=$9
    YLEN=${10}
    M=""
    #jump/step length
    sl=${11}
    end_frame=${12}
    dt=${13}
    rt=${14}
    XTICKDIST=${15}
    YTICKDIST=${16}
    BGCOLOR=${17}
    FILLCOLOR=${18}

    T=''
    cp $basedir/surface_snapshot.tex $fig/tex/
    cmd="$basedir/surface_snapshot -fig $fig -ob $ob"
    echo $input_dir
    echo $Xcaption
    cmd="$cmd -i $input_dir -dt $dt -sl $sl -e $end_frame -fill $FILLCOLOR"
    if [ $rt -eq 1 ]
    then
        cmd="$cmd -rt"
    fi
    cmd="$cmd || exit 1"
    echo $cmd
    $cmd
    wait
    #     for file in $input_dir"_"*$ob.txt; do
    for file in $fig/tex/surface_snapshot_$input_dir*.tex; do
        tex_file=${file%.*}
        #       echo $tex_file
        #        cp surface_snapshot.tex $fig/$tex_file.tex
        sed -i -e "s@FIG@$fig@g" -e "s/YY/y/g" -e "s/XX/x/g" -e "s/YCAPTION/$Ycaption/g" -e "s/XCAPTION/$Xcaption/g" -e "s/MMM/$M/g" -e "s/QQ/$U/g" -e "s/YMAX/$YMAX/g" -e "s/YMIN/$YMIN/g" -e "s/XMAX/$XMAX/g" -e "s/XMIN/$XMIN/g" -e "s/XLEN/$XLEN/g" -e "s/YLEN/$YLEN/g" -e "s/TTT/$T/" -e "s/NNN/$D/"  -e "s/XTICKDIST/$XTICKDIST/g" -e "s/YTICKDIST/$YTICKDIST/g" -e "s/BGCOLOR/$BGCOLOR/g" $file
        pdflatex -halt-on-error -output-directory=$fig/pdfs $file
    done
    for file in $fig/pdfs/surface_snapshot_"$input_dir"*.pdf; do
        cp $file $fig
    done
}

function create_db_graph()
{
    od=$1
    YMIN=$2
    YMAX=$3
    XMIN=$4
    XMAX=$5
    filename=$6
    max_x_tex=$fig/tex/$od"_max_x".tex
    max_y_tex=$fig/tex/$od"_max_y".tex
    cp $sc/db_max_x.tex $max_x_tex
    cp $sc/db_max_y.tex $max_y_tex
    sed -i -e "s@FIG@$fig@g" -e "s/YY/x/g" -e "s/XX/t/g" -e "s/YCAPTION/Z/g" -e "s/XCAPTION/T/g"  -e "s/YMAX/$XMAX/g" -e "s/YMIN/$XMIN/g" -e "s/XMAX/2.5/g" -e "s/XMIN/0/g"  -e "s/NNN/2/"  -e "s/DIRR/$od/g" -e "s/FILEEE/$filename/g" $max_x_tex
    sed -i -e "s@FIG@$fig@g" -e "s/YY/y/g" -e "s/XX/t/g" -e "s/YCAPTION/H/g" -e "s/XCAPTION/T/g"  -e "s/YMAX/$YMAX/g" -e "s/YMIN/$YMIN/g" -e "s/XMAX/2.5/g" -e "s/XMIN/0/g"  -e "s/NNN/2/"  -e "s/DIRR/$od/g" -e "s/FILEEE/$filename/g" $max_y_tex
    pdflatex -halt-on-error -output-directory=$fig/pdfs $max_x_tex
    pdflatex -halt-on-error -output-directory=$fig/pdfs $max_y_tex
    cp $fig/pdfs/$od"_max_x".pdf $fig
    cp $fig/pdfs/$od"_max_y".pdf $fig
}

function create_rt_graph()
{
    od=$1
    YMIN=$2
    YMAX=$3
    filename=$4
    min_max_x_tex=$fig/tex/$od"_min_max_x".tex
    cp $sc/highest_lowest_point.tex $min_max_x_tex
    sed -i -e "s@FIG@$fig@g" -e "s/YY/y/g" -e "s/XX/t/g" -e "s/YCAPTION/H/g" -e "s/XCAPTION/t/g" -e "s/YMAX/$YMAX/g" -e "s/YMIN/$YMIN/g" -e "s/XMAX/2.5/g" -e "s/XMIN/0/g"  -e "s/NNN/2/"  -e "s/DIRR/$od/g" -e "s/FILEEE/$filename/g" $min_max_x_tex
    pdflatex -halt-on-error -output-directory=$fig/pdfs $min_max_x_tex
    cp $fig/pdfs/$od"_min_max_x".pdf $fig
}


#
wait


