//##############################################################################
// MAY 2023-Mehrnaz Ayazi
//##############################################################################
#include <Core/Arrays/ARRAY.h>
#include <Core/Arrays/FACE_ARRAYS.h>
#include <Core/Grids/CELL_ITERATOR.h>
#include <Core/Grids/GRID.h>
#include <Core/Grids_Uniform_Computations/MARCHING_CUBES.h>
#include <Core/Images/TEX_FILE.h>
#include <Core/Interpolation/AVERAGING_UNIFORM.h>
#include <Core/Math_Tools/RANGE.h>
#include <Core/Math_Tools/RANGE_ITERATOR.h>
#include <Core/Meshes/MESH_OBJECT.h>
#include <Core/Meshes/SEGMENTED_CURVE.h>
#include <Core/Parsing/PARSE_ARGS.h>
#include <Core/Read_Write/FILE_UTILITIES.h>
#include <Core/Utilities/PROCESS_UTILITIES.h>
#include <Core/Utilities/VIEWER_DIR.h>

using namespace PhysBAM;

typedef double T;
typedef VECTOR<T,2> TV;
typedef VECTOR<int,2> IV;

std::string fig_dir;
ARRAY<std::string> dir;
//#####################################################################
// Function Dump_Circularity_data
//#####################################################################
void Dump_Curvature_data(const std::string& file,int frame)
{
    for(int i=0;i<dir.m;i++)
    {
        std::ofstream stream(fig_dir+"/txt/"+dir(i)+"_"+file);
        LOG::cout<<fig_dir+"/txt/"+dir(i)+"_"+file<<std::endl;
        LOG::fprintf(stream,"x y curvature\n");
        VIEWER_DIR viewer_dir(fig_dir+"/"+dir(i));
        viewer_dir.Set(frame);
        GRID<TV> grid;
        ARRAY<T,IV> curvature;
        Read_From_File(viewer_dir.Common_File("grid"),grid);
        Read_From_File(viewer_dir.Frame_File("curvature"),curvature);
        for(CELL_ITERATOR<TV> it(grid);it.Valid();it.Next())
        {
            LOG::fprintf(stream,"%p %p %p\n",it.Location()(0),it.Location()(1),curvature(it.index));
        }
    }
}
//#####################################################################
// Function main
//#####################################################################
int main(int argc,char *argv[])
{
    PROCESS_UTILITIES::Set_Floating_Point_Exception_Handling(true);
    PROCESS_UTILITIES::Set_Backtrace(true);

    PARSE_ARGS parse_args(argc,argv);
    LOG::Initialize_Logging(false,false,1<<30,true);
    LOG::cout<<parse_args.Print_Arguments()<<std::endl;

    VECTOR<T,2> range_scale={0,1};
    std::string boundary_file="";
    int frame=0;
    parse_args.Add("-ob",&boundary_file,"string-file name","file name for data");
    parse_args.Add("-i",&dir,"string-directory name","directory name to read data from");
    parse_args.Add("-frame",&frame,"scalar-int","frame_dt");
    parse_args.Add("-fig",&fig_dir,"dir","base figure directory");

    parse_args.Parse();

    std::string boundary_file_text=boundary_file+".txt";
    Dump_Curvature_data("curvature_"+boundary_file_text,frame);
    LOG::Finish_Logging();
    return 0;
}
