#! /usr/bin/env bash
#===================================================================
# Simulates a bubble of low density fluid surrounded by high density fluid
# bubble should rise slightly over time
# Used to compare rising velocity,circularity, center of mass with reference implementations
# Generates 6 different cases, each in 5 different resolutions [16,32,64,128,256]
# case 1: Xeta=0, XM=1
# case 2: Xeta=0.3333, XM=1
# case 3: Xeta=0.5, XM=1
# case 4: Xeta=0.6666, XM=1
# case 5: Xeta=0.6666, XM=1.5
# case 6: Xeta=1, XM=1
# Usage: air_bubble_test.sh <fig> [test number=0] [optional argument=none]
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
option=$2

CMD="$basedir/chns -test 16 -second_order -st_type 2 -ch_h_tol 1e-12 -mu_tol 1e-12 -p_tol 1e-12 "

if [ $test -eq 0 ]
then
    res=16
    dt=0.008
    end_frame=160
    sigma=1.96
    CMD="$CMD -e $end_frame -frame_dt $dt -res $res -ch_sigma $sigma -mu0 0.1 -mu1 10 -rho0 1 -rho1 1000 $option"
    for refine in 1 2 4 8 16; do
        eta0=$(perl -e 'print 1/32')
        h=$(perl -e 'print 1/(16*'$refine')')
        h0=$(perl -e 'print 1/32')
        M0=$(perl -e 'print 10**(-7)')

        # Case 1
        Xeta=0
        XM=1
        eta=$(perl -e 'print '$eta0'*('$h'/'$h0')**'$Xeta)
        M=$(perl -e 'print '$M0'*('$eta'/'$eta0')**'$XM)
           
        echo $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-1-$refine
        $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-1-$refine >/dev/null &

        # Case 2
        Xeta=0.3333
        XM=1
        eta=$(perl -e 'print '$eta0'*('$h'/'$h0')**'$Xeta)
        M=$(perl -e 'print '$M0'*('$eta'/'$eta0')**'$XM)

        echo $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-2-$refine
        $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-2-$refine >/dev/null &

        # Case 3
        Xeta=0.5
        XM=1
        eta=$(perl -e 'print '$eta0'*('$h'/'$h0')**'$Xeta)
        M=$(perl -e 'print '$M0'*('$eta'/'$eta0')**'$XM)

        echo $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-3-$refine
        $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-3-$refine >/dev/null &

        # Case 4
        Xeta=0.6666
        XM=1
        eta=$(perl -e 'print '$eta0'*('$h'/'$h0')**'$Xeta)
        M=$(perl -e 'print '$M0'*('$eta'/'$eta0')**'$XM)

        echo $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-4-$refine
        $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-4-$refine >/dev/null &

        # Case 5
        Xeta=0.6666
        XM=1.5
        eta=$(perl -e 'print '$eta0'*('$h'/'$h0')**'$Xeta)
        M=$(perl -e 'print '$M0'*('$eta'/'$eta0')**'$XM)

        echo $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-5-$refine
        $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-5-$refine >/dev/null &

        # Case 6
        Xeta=1
        XM=1
        eta=$(perl -e 'print '$eta0'*('$h'/'$h0')**'$Xeta)
        M=$(perl -e 'print '$M0'*('$eta'/'$eta0')**'$XM)

        echo $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-6-$refine
        $CMD -ch_M $M -ch_eta $eta -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble-6-$refine >/dev/null &
    done
    wait
elif [ $test -eq 1 ] # density ratio 1000
then
    sigma=1
    refine=8
    end_frame=2000
    dt=0.001
    M="1e-7"
    eta=0.1
    echo $CMD -ch_M $M -ch_eta $eta -rho0 1 -rho1 1000 -range_max "1 2" -res_v "8 16" -refine $refine -gravity_v "0 -9.8" -o $fig/air_bubble_$test
    $CMD -mu0 0.1 -mu1 0.1 -ch_sigma $sigma -ch_M $M -ch_eta $eta -rho0 1 -rho1 1000 -frame_dt $dt -e $end_frame -range_max "1 2" -res_v "8 16" -refine $refine -gravity_v "0 -9.8" -o $fig/air_bubble_$test &
    wait
elif [ $test -eq 2 ] 
then
    # for resx in 16 32 64 128 256; do
    sigma=24.5
    for resx in 16 32 64 128; do
        eta0=$(perl -e 'print 1/32')
        h=$(perl -e 'print 1/'$resx)
        h0=$(perl -e 'print 1/32')
        M0=$(perl -e 'print 10**(-7)')
        Xeta=$(perl -e 'print 1')
        XM=$(perl -e 'print 2')
        eta=$(perl -e 'print '$eta0'*('$h'/'$h0')**'$Xeta)
        M=$(perl -e 'print '$M0'*('$eta'/'$eta0')**'$XM)
        dt=$(perl -e 'print 0.128*'$h)
        end_frame=$(perl -e 'print 1/'$dt)
        $CMD -mu0 1 -mu1 10 -ch_sigma $sigma -ch_M $M -ch_eta $eta -rho0 100 -rho1 1000 -frame_dt $dt -e $end_frame -res $resx -refine 1 -gravity_v "0 -.98" -o $fig/air_bubble_$test-$resx &
    done
    wait
# density ratio 10
elif [ $test -eq 3 ] 
then
   sigma=1
       refine=8
       end_frame=2000
       dt=0.001
       M=1
       eta=0.04
       echo $CMD -ch_M $M -ch_eta $eta -rho0 1 -rho1 10 -range_max "1 2" -res_v "8 16" -refine $refine -gravity_v "0 -9.8" -o $fig/air_bubble_$test
       $CMD -mu0 0.1 -mu1 0.1 -ch_sigma $sigma -ch_M $M -ch_eta $eta -rho0 1 -rho1 10 -frame_dt $dt -e $end_frame -res 8 -refine $refine -gravity_v "0 -.98" -o $fig/air_bubble_$test &
       wait
    
fi

wait
