#! /usr/bin/env bash
#===================================================================
# Simulates phase separation purely due to Cahn-Hilliard
# Runs at 6 different refinement levels
# Usage: ch_evolution_test.sh <fig> [test number=0] [optional argument=none]
#===================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-1}
option=$2

if [ $test -eq 0 ]
then
    # generic case, no reference paper
    refine=32
    CMD="$basedir/chns -test 0 -random_gamma 1 -second_order -e 1000 -frame_dt 0.1 -res 8 -ch_sigma 1e-2 -ch_eta 0.01 -ch_M 1e-2 -rho0 1 -rho1 1000 -mu0 0 -mu1 0 $option -no_adv -no_st_force -no_viscosity -spf 10 -mu_tol 1e-12 -p_tol 1e-12 -ch_h_tol 1e-12 "
    echo $CMD -refine $refine -periodic -range_scale "0 1" -o $fig/ch_test_$test
    $CMD -refine $refine -periodic -range_scale "0 1" -o $fig/ch_test_$test >/dev/null &
elif [ $test -eq 1 ]
then
    # default case
    # On-large-time-stepping-methods-for-the-Cahn-Hilliard-equation.pdf
    # range=0,2pi
    # res=256/512
    res=512
    # periodic
    # ML=eta^2
    # eta^2=0.001?
    eta=0.03162277660
    M=0.02981423968
    sigma=1
    # random values between 0.475 and 0.525
    randomscale=0.05
    dt=0.01 # x100 to have fewer frames printed
    endtime=500
    spf=100
    CMD="$basedir/chns -test 0 -random_gamma $randomscale -second_order -e $endtime -frame_dt $dt -res $res -ch_sigma $sigma -ch_eta $eta -ch_M $M -rho0 1 -rho1 1 -mu0 0 -mu1 0 $option -no_adv -no_st_force -no_viscosity -spf $spf -mu_tol 1e-12 -p_tol 1e-12 -ch_h_tol 1e-12 "
    echo $CMD -periodic -range_scale '"0 6.283185308"' -o $fig/ch_test_$test
    $CMD -periodic -range_scale "0 6.283185308" -o $fig/ch_test_$test >/dev/null &
elif [ $test -eq 2 ]
then
    # physical-mathematical-and-numerical-derivations-of-the-cahn-hilliard-equation.pdf
    # too much redistribution error, even after cutting dt by 100
    # range 0,1
    # dx=0.0026?
    res=385
    # ML=eta^2
    # eta=4*dx/(2*sqrt(2)*atanh(0.9))=0.005?
    eta=0.002495064089 # ?
    M=0.002352368982 # ?
    sigma=1
    # random values between 0.49 and 0.51
    randomscale=0.02
    dt=0.0001
    endtime=300000
    CMD="$basedir/chns -test 0 -random_gamma $randomscale -second_order -e $endtime -frame_dt $dt -res $res -ch_sigma $sigma -ch_eta $eta -ch_M $M -rho0 1 -rho1 1 -mu0 0 -mu1 0 $option -no_adv -no_st_force -no_viscosity -spf 1 -mu_tol 1e-12 -p_tol 1e-12 -ch_h_tol 1e-12 -ch_b_tol 1e-9 "
    echo $CMD -range_scale '"0 1"' -o $fig/ch_test_$test
    $CMD -range_scale "0 1" -o $fig/ch_test_$test >/dev/null &
elif [ $test -eq 3 ]
then
    # Computationally-efficient-adaptive-time-step-method-for-the-Cahn-Hilliard-equation.pdf
    # references coarsening-kinetics-from-a-variable-mobility-cahn-hilliard-equation-application-of-a-semi-implicit-fourier-spectral-method.pdf
    #    this paper is periodic? not many parameter found in that paper
    # range 0, 1024
    res=1024
    # non-periodic?
    # ML=eta^2 = 0.9227517340 ?
    M=0.9056620585 # ?
    sigma=1 
    # eta=4*dx/(2*sqrt(2)*atanh(0.9))
    eta=0.9605996739 # ?
    # random values between 0.45 and 0.55
    randomscale=0.1
    dt=1
    endtime=30000
    CMD="$basedir/chns -test 0 -random_gamma $randomscale -second_order -e $endtime -frame_dt $dt -res $res -ch_sigma $sigma -ch_eta $eta -ch_M $M -rho0 1 -rho1 1 -mu0 0 -mu1 0 $option -no_adv -no_st_force -no_viscosity -spf 1  -mu_tol 1e-12 -p_tol 1e-12 -ch_h_tol 1e-12 -ch_b_tol 1e-7 "
    echo $CMD -range_scale '"0 1024"' -o $fig/ch_test_$test
    $CMD -range_scale "0 1024" -o $fig/ch_test_$test >/dev/null &
elif [ $test -eq 4 ]
then
    # Second-order-schemes-and-time-step-adaptivity-for-Allen-Cahn-and-Cahn-Hilliard-models.pdf
    # references on-linear-schemes-for-a-cahn-hilliard-diffuse-interface-model.pdf
    #    reference paper uses the same parameters
    # Finished without issue at current parameters (after a very long time, should cut number of frames printed by 1000)
    # range=0,1
    res=90
    # non-periodic?
    # ML=0.0001
    M=0.009428090411
    eta=0.01
    sigma=1
    # random values between 0.495 and 0.505
    randomscale=0.01
    dt=0.01
    endtime=2500
    spf=1000
    CMD="$basedir/chns -test 0 -random_gamma $randomscale -second_order -e $endtime -frame_dt $dt -res $res -ch_sigma $sigma -ch_eta $eta -ch_M $M -rho0 1 -rho1 1 -mu0 0 -mu1 0 $option -no_adv -no_st_force -no_viscosity -spf $spf -mu_tol 1e-12 -p_tol 1e-12 -ch_h_tol 1e-12 -ch_b_tol 1e-9 "
    echo $CMD -range_scale '"0 1"' -o $fig/ch_test_$test
    $CMD -range_scale "0 1" -o $fig/ch_test_$test >/dev/null &
fi
wait    
