#! /usr/bin/env bash
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
M=1
sigma=1
eta=0.1
dt=0.001
end_frame=10
option=$2
use_out=$3
res="04 08 16"
#res="02 04 06 08"
#res="01"

if [ "X$use_out" = "X1" ] ; then
    use_out="-substeps 1 -error_output"
else
    use_out="-suppress_output"
fi

rm -f $fig/tmp-*txt

CMD="$basedir/chns -res 8 -test 1 -e $end_frame -frame_dt $dt -M $M -sigma $sigma -rho0 10 -rho1 10 -eta $eta $use_out $option -no_st_force"

ALL=""
(

# function run()
# {
#     TEST=$1
#     ALL="$ALL $TEST"
#     [ $test -eq 0 ] || [ $test -eq $TEST ] || return
#     CODE="$2"
#     shift 2
#     EXTRA="$@"
#     (
#         for i in $res; do
#             echo $CMD -refine $i -o $fig/source_outputs/test"$TEST"_$i -ch_code "$CODE" $EXTRA
#             $CMD -refine $i -o $fig/source_outputs/test"$TEST"_$i -ch_code "$CODE" $EXTRA | grep L2 | tail -n 30 > $fig/tmp-$TEST-$i.txt &
#             base="$fig/tmp-$TEST-$i.txt"
#         done
#         wait
        
#         awk '{print $3}' "$base" > $fig/tmp-out-$TEST.txt
#         for i in $res; do
#             awk '{print $8}' "$fig/tmp-$TEST-$i.txt" > $fig/tmp-r-$TEST.txt
#             paste $fig/tmp-out-$TEST.txt $fig/tmp-r-$TEST.txt > $fig/tmp-q-$TEST.txt
#             mv $fig/tmp-q-$TEST.txt $fig/tmp-out-$TEST.txt
#         done
#         mv $fig/tmp-out-$TEST.txt $fig/tmp-q-$TEST.txt
#         echo "testing $CODE" > $fig/tmp-out-$TEST.txt
#         cat $fig/tmp-q-$TEST.txt >>$fig/tmp-out-$TEST.txt
#     ) &
    # }

function run()
{
    TEST=$1
    ALL="$ALL $TEST"
    [ $test -eq 0 ] || [ $test -eq $TEST ] || return
    CODE="$2"
    shift 2
    EXTRA="$@"
    (
        for i in $res; do
            echo $CMD -refine $i -o $fig/source_outputs/test"$TEST"_$i -code "$CODE" $EXTRA
            $CMD -refine $i -o $fig/source_outputs/test"$TEST"_$i -code "$CODE" $EXTRA > $fig/log-$TEST-$i.txt &
        done
        wait
        
        $basedir/convergence_order.pl $fig/log-$TEST-*.txt > $fig/order-$TEST.txt
        echo "testing $CODE" > $fig/summary-$TEST.txt
        #awk '$4 != "S" {print $1 " " $2 " " $3}' $fig/order-$TEST.txt | column -t >> $fig/summary-$TEST.txt
        awk '{print $1 " " $2 " " $3 " " $4}' $fig/order-$TEST.txt | column -t >> $fig/summary-$TEST.txt
    ) &
}

# gamma tests
run 1 "gamma=x;u=0;v=0;p=0;"
run 2 "gamma=(x-0.5)^2+0.5;u=0;v=0;p=0;"
run 3 "gamma=x^3;u=0;v=0;p=0;"
run 4 "gamma=x^3*y;u=0;v=0;p=0;"
run 5 "gamma=(sin(2*pi*x)+1)/2;u=0;v=0;p=0;"
run 6 "gamma=(sin(2*pi*x)+1)/2;u=0;v=0;p=0;"  -periodic
run 7 "gamma=(cos(2*pi*x)*cos(2*pi*y)*sin(2*pi*t)+1)/2;u=0;v=0;p=0;"
run 8 "gamma=(cos(2*pi*x)*cos(2*pi*y)*sin(2*pi*t)+1)/2;u=0;v=0;p=0;" -periodic
run 9 "gamma=(cos(2*pi*x)*cos(2*pi*y)+1)*(0.5+10*t);u=0;v=0;p=0;" -periodic
run 10 "gamma=2*t;u=0;v=0;p=0;" -periodic
run 101 "gamma=(cos(2*pi*x)+1)/2;u=0;v=0;p=0;" -periodic
run 102 "gamma=(cos(2*pi*x)+1)/2*t;u=0;v=0;p=0;" -periodic
run 103 "gamma=(cos(2*pi*x)+1)*(0.5+10*t);u=0;v=0;p=0;" -periodic
run 104 "gamma=16*x*x*(1-x)*(1-x)*t;u=0;v=0;p=0;"
run 105 "gamma=x*t;u=0;v=0;p=0;"
run 106 "gamma=x*y*t;u=0;v=0;p=0;"
run 107 "gamma=x^3*t;u=0;v=0;p=0;"
run 108 "gamma=x^3*(1-t);u=0;v=0;p=0;"
run 110 "gamma=cos(x);u=0;v=0;p=0;"
run 111 "gamma=16*x*x*(1-x)*(1-x);u=0;v=0;p=0;"
run 112 "gamma=2*t^2;u=0;v=0;p=0;"
run 113 "gamma=2*t^3+0.5*t^2;u=0;v=0;p=0;"
run 114 "gamma=cos(t);u=0;v=0;p=0;"
run 115 "gamma=exp(-t)*cos(x);u=0;v=0;p=0;"

# uv tests
run 11 "gamma=0;u=1;v=0;p=0;"
run 12 "gamma=0;u=1;v=1;p=0;"
run 13 "gamma=0;u=-x*(x-1)*(3*y^2-1);v=y*(y-1)*(y+1)*(2*x-1);p=0;"
run 14 "gamma=0;u=-x*(x-1)*(3*y^2-1)*t;v=y*(y-1)*(y+1)*(2*x-1)*t;p=0;"
run 15 "gamma=1;u=y;v=0;p=0;"
run 16 "gamma=0;u=-x*(x-1)*(3*y^2-1)*(1+t);v=y*(y-1)*(y+1)*(2*x-1)*(1+t);p=0;"
run 17 "gamma=1;u=0;v=x;p=0;"

# p tests
run 21 "gamma=0;u=0;v=0;p=1;"
run 22 "gamma=0;u=0;v=0;p=x;"
run 23 "gamma=0;u=0;v=0;p=x^2;"
run 24 "gamma=0;u=0;v=0;p=x^3+2;"
run 25 "gamma=0;u=0;v=0;p=x^3*y+2*y;"
run 26 "gamma=0;u=0;v=0;p=5*sin(x);"
run 27 "gamma=0;u=0;v=0;p=10*t;"
run 28 "gamma=0;u=0;v=0;p=x^2*y*10*t;"

# gamma and p tests
run 31 "gamma=x;u=0;v=0;p=x;"
run 32 "gamma=x^2*y^3;u=0;v=0;p=cos(x)*y^2;"
run 33 "gamma=(cos(2*pi*x)*cos(2*pi*y)*sin(2*pi*t)+1)/2;u=0;v=0;p=x^2*y*10*t;"
run 34 "gamma=cos(2*pi*x)*cos(2*pi*y)*cos(2*pi*t);u=0;v=0;p=x^2*y*(1+t);"

# uv and p tests
run 41 "gamma=-1;u=1;v=0;p=1;"
run 42 "gamma=-1;u=1;v=1;p=x^2*y;"
run 43 "gamma=-1;u=-x*(x-1)*(3*y^2-1);v=y*(y-1)*(y+1)*(2*x-1);p=x^2*y;"
run 44 "gamma=-1;u=-x*(x-1)*(3*y^2-1);v=y*(y-1)*(y+1)*(2*x-1);p=cos(x)*sin(y);"
run 45 "gamma=-1;u=-x*(x-1)*(3*y^2-1)*t;v=y*(y-1)*(y+1)*(2*x-1)*t;p=cos(x)*sin(y)*t;"
run 46 "gamma=-1;u=-x*(x-1)*(3*y^2-1)*(1+t);v=y*(y-1)*(y+1)*(2*x-1)*(1+t);p=cos(x)*sin(y)*(1+t);"
run 47 "gamma=-1;u=-x*(x-1)*(3*y^2-1);v=y*(y-1)*(y+1)*(2*x-1);p=cos(x)*sin(y)*cos(t);"
run 48 "gamma=-1;u=-x*(x-1)*(3*y^2-1)*t;v=y*(y-1)*(y+1)*(2*x-1)*t;p=cos(x)*sin(y)*(t^2);"

# gamma, uv, and p tests
run 51 "gamma=0;u=0;v=0;p=0;"
run 52 "gamma=2*x^2*y-1;u=1;v=1;p=x*y;"
run 53 "gamma=2*x^2*y-1;u=-x*(x-1)*(3*y^2-1);v=y*(y-1)*(y+1)*(2*x-1);p=x*y;"
run 54 "gamma=cos(2*pi*x)*cos(2*pi*y);u=-x*(x-1)*(3*y^2-1);v=y*(y-1)*(y+1)*(2*x-1);p=x^3+y^2;"
run 55 "gamma=cos(2*pi*x)*sin(2*pi*y)*cos(2*pi*t);u=-x*(x-1)*(3*y^2-1);v=y*(y-1)*(y+1)*(2*x-1);p=x^3+y^2;"
run 56 "gamma=cos(2*pi*x)*sin(2*pi*y)*cos(2*pi*t);u=-x*(x-1)*(3*y^2-1)*(1+t);v=y*(y-1)*(y+1)*(2*x-1)*(1+t);p=10*t*(x^3+y^2);"


# paper test
#if [ $test -eq 0 -o $test -eq 99 ]
#then    
#    echo "testing paper solution (pi range)"
#    for i in 1 2 4 8; do
#        echo loop $i
#        $CMD -refine $i -o $fig/source_outputs/test99_$i -cfl 1 -frame_dt 0.001 -M 0.001 -sigma 0.00942809 -rho0 3 -rho1 1 -mu0 0.02 -mu1 0.01 -gravity -ch_code "gamma=cos(x)*cos(y)*sin(t);u=sin(x)*cos(y)*cos(t);v=-cos(x)*sin(y)*cos(t);p=cos(x)*cos(y)*sin(t);" -eta 0.1 -substeps 1 -range_scale "3.14159265359 3.14159265359" | grep L2 | tail -n 4
#    done
#fi

wait
)

rm $fig/log-*.txt

for i in $fig/summary-*.txt ; do
    echo ==== $i ====
    cat $i 
done
rm -f $fig/summary-*.txt
