#! /usr/bin/env bash
#=================================================================
# Usage: constant_b_test.sh <fig> 
#=================================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

end_frame=${1:-1}
option=$2
code_in=$3
sigma=0.00942809 # chosen such that lambda=1e-3
dt=0.01
refine=16
use_out="-suppress_output"

CMD="$basedir/chns -test 1 -ch_M 0.001 -ch_sigma $sigma -rho0 1 -rho1 3 -mu0 0.01 -mu1 0.02 -ch_eta 0.1 -source_sym -test_sym -second_order $use_out -ch_h_tol 1e-15 -p_tol 1e-15 -mu_tol 1e-15 -st_type 5 -div_free -ch_optimizer -ch_min 0.1 -res 8 -refine $refine -frame_dt $dt -spf 1 -e $end_frame $option"

if [ -z "$code_in" ]
then
    CODE="gamma=1/2+cos(x)*cos(y)*(1-sin(t))/2.1;u=sin(x)*cos(y)*cos(t);v=-cos(x)*sin(y)*cos(t);p=cos(x)*cos(y)*sin(t);"
#    CODE="gamma=1/2+cos(x)*cos(y)*(1-sin(t))/2.1;u=0;v=0;p=0;"
else
    CODE="$code_in"
fi
directory=$fig/"q_nonperiodic_test_"$end_frame"_opt"

mkdir $directory
echo "testing q constant (pi range)"
for q in 0.99 0.9 0.8 0.7 0.6 0.5 0.4 0.3 0.2 0.1 1e-2 1e-3 1e-4 1e-5 1e-6; do
(
    echo $CMD -gravity_v "\"1 -2\"" -o $fig/constant_q_outputs/test_"$q" -code "\"""$CODE""\"" -ch_q "$q"
    output=$( $CMD -gravity_v "1 -2" -o $fig/constant_q_outputs/test_"$q" -code "$CODE" -ch_q "$q")
    echo "${output}" | grep "gamma2" | tail -n 1 > $directory/log_"$q".txt  
    echo "${output}" | grep "q=" | tail -n 1 > $directory/log_"$q"_b.txt  
)&
done
wait

# output table for figure generation
rm $directory/q_error_table.txt
# echo "q b l2err linferr" >> $directory/q_error_table.txt
for q in 0.99 0.9 0.8 0.7 0.6 0.5 0.4 0.3 0.2 0.1 1e-2 1e-3 1e-4 1e-5 1e-6; do
    b=$(cat $directory/log_"$q"_b.txt | awk -F'[:blank:]|=' '{print $5}')
    l2err=$(cat $directory/log_"$q".txt | awk '{print $8}')
    linferr=$(cat $directory/log_"$q".txt | awk '{print $12}')
    # echo $directory/log_"$q".txt
    # echo "$b" "$q" "$l2err" "$linferr"
    echo "$b" "$q" "$l2err" "$linferr" >> $directory/q_error_table.txt
done
echo "logging table to $directory/q_error_table.txt"

