#! /usr/bin/env bash
#========================================================
# By default, runs a dam break test at a density ratio of approximately 1000 (water/air)
# Usage: dam_break_test.sh <fig> [test number=0] [optional argument=none]
#========================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
# end_frame=80000 # end at t=2
# dt=0.000025
# steps=1
end_frame=200 # end at t=2
dt=0.01
steps=40
refine=10
option=$2
eta=0.01
M=0 # chosen so that program automatically calculates M such that L*M=1e-7

# density/1.204     <=== used
# viscosity/1.204   <=== used
# sigma = kg/s^2 ???

# viscosity/rho_air/0.01/0.01?
# eta/0.01?

CMD=($basedir/chns -refine $refine -frame_dt $dt -e $end_frame -spf $steps -second_order -rho0 1 -rho1 829.076 -mu0 1.48e-5 -mu1 8.322e-4 -ch_sigma 7.28e-2 -ch_eta $eta -ch_M $M -st_type 2 -ch_h_tol 1e-12 -mu_tol 1e-12 -p_tol 1e-12 -range_min "-0.5 0" -range_max "0.5 1.5" -res_v "10 15" -gravity_v "0 -9.8" -m 0.01 -o $fig/contact_angle_$test $option)

if [ $test -eq 0 ]
then
    CMD+=(-test 32)
elif [ $test -eq 1 ];
then
    CMD+=(-test 33)
elif [ $test -eq 2 ];
then
    CMD+=(-test 34)
elif [ $test -eq 3 ];
then
    CMD+=(-test 35)
fi

echo "${CMD[@]}"
"${CMD[@]}" >/dev/null &
wait
