#! /usr/bin/env bash
#========================================================
# By default, runs a dam break test at a density ratio of approximately 1000 (water/air)
# Usage: dam_break_test.sh <fig> [test number=0] [optional argument=none]
#========================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
# end_frame=20000 # end at t=1
# dt=0.00005
# steps=1
# end_frame=200 # end at t=1
# dt=0.005
# steps=100
end_frame=125 # end at t=1
dt=0.008
steps=10
refine=16
option=$2
eta=0.02
# M=0 # chosen so that program automatically calculates M such that L*M=1e-7
M="1.885e-7"

# res_v was 385 128, which is not square?

CMD=($basedir/chns -test 36 -refine $refine -frame_dt $dt -e $end_frame -spf $steps -second_order -rho0 1 -rho1 1 -mu0 1 -mu1 1 -ch_sigma 100 -ch_eta $eta -ch_M $M -st_type 2 -ch_h_tol 1e-12 -mu_tol 1e-12 -p_tol 1e-12 -range_min "-3 0" -range_max "3 2" -res_v "24 8" -gravity_v "0 0" -m 1 -o $fig/equilibrium_$test $option)

if [ $test -eq 0 ]
then
    CMD+=(-contact "90 90 90 90")
elif [ $test -eq 1 ];
then
    CMD+=(-contact "90 90 45 90")
elif [ $test -eq 2 ];
then
    CMD+=(-contact "90 90 135 90")
elif [ $test -eq 3 ];
then
    CMD+=(-contact "90 90 60 90")
elif [ $test -eq 4 ];
then
    CMD+=(-contact "90 90 120 90")
fi

echo "${CMD[@]}"
"${CMD[@]}" >/dev/null &
wait
