#! /usr/bin/env bash
#========================================================
# By default, runs a rayleigh-taylor test at a density ratio of 3
# TEST #  rho0  rho1
#   0       1     3
#   1       1     30         Needs to run at least until frame 50
#   2       1     1000       Needs to run at least until frame 50
#   3       1     3000       Needs to run at least until frame 50
# Usage: rayleight-taylor_test.sh <fig> [test number=0] [optional argument=none]
#========================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
steps=100
sigma="1e-12"
tol="1e-12"
eta=0.01 # could be different
M=0.09428090411 # chosen so that L*M=1e-15
option=$2
# dt=0.05

# density ratio 3
if [ $test -eq 0 ]
then
    end_frame=160
    dt=0.070711
    rho1=3
elif [ $test -eq 1 ]
then
    # density ratio 30
    steps=400
    # option="$option -no_require_convergence"
    end_frame=160
    dt=0.051695
    rho1=30
elif [ $test -eq 2 ]
then
    # density ratio 1000
    steps=400
    end_frame=160
    dt=0.050050
    rho1=1000
elif [ $test -eq 3 ]
then
    # density ratio 3000
    steps=400
    end_frame=160
    dt=0.050017
    rho1=3000
fi
res=128
refine=1
CMD="$basedir/chns -test 17 -frame_dt $dt -spf $steps -e $end_frame -res $res -refine $refine $option -second_order -st_type 2 -ch_h_tol $tol -mu_tol $tol -p_tol $tol -ch_M $M -ch_eta $eta -ch_sigma $sigma -rho0 1 -mu0 0.001 -mu1 0.001"

echo  $CMD -rho1 $rho1 -gravity_v "0 -1" -periodic_v "1 0" -o $fig/rayleigh-taylor_$test &
$CMD -rho1 $rho1 -gravity_v "0 -1" -periodic_v "1 0" -o $fig/rayleigh-taylor_$test >/dev/null &
 
wait
