#! /usr/bin/env bash
#========================================================
# By default, runs a dam break test at a density ratio of approximately 1000 (water/air)
# Usage: dam_break_test.sh <fig> [test number=0] [optional argument=none]
#========================================================
basedir="$PROJ/chns_project"
ex="$basedir/example_scripts"
sc="$basedir/Figures/scripts"

fig="$1"
mkdir -p $fig/logs $fig/tex $fig/txt $fig/pdfs
shift

test=${1:-0}
end_frame=1000
dt=0.001
steps=1
option=$2
eta=0.1
M=0 # chosen so that program automatically calculates M such that L*M=1e-7
# M="1e-3"
q=0.5
res=8
refine=8
mu0=0
mu1=0
rho0=1
rho1=1000
sigma="7.28e-2"

CMD="$basedir/chns -test 31 -frame_dt $dt -e $end_frame -spf $steps -res $res -refine $refine -ch_optimizer -ch_q $q -second_order -mu0 $mu0 -mu1 $mu1 -rho0 $rho0 -rho1 $rho1 -ch_sigma $sigma -ch_eta $eta -ch_M $M -st_type 2 -ch_h_tol 1e-12 -mu_tol 1e-12 -p_tol 1e-12 -no_st_force $option "
# CMD="$basedir/chns -test 31 -frame_dt $dt -e $end_frame -spf $steps -res $res -refine $refine -second_order -mu0 $mu0 -mu1 $mu1 -rho0 $rho0 -rho1 $rho1 -ch_sigma $sigma -ch_eta $eta -ch_M $M -st_type 2 -ch_h_tol 1e-12 -mu_tol 1e-12 -p_tol 1e-12 -no_st_force $option "

if [ $test -eq 0 ]
then
    echo $CMD -gravity_v "0 0" -o $fig/shearing_$test &
    $CMD -gravity_v "0 0" -o $fig/shearing_$test >/dev/null &
    wait
elif [ $test -eq 1 ]
then
    echo $CMD -invert_gamma -gravity_v "0 0" -o $fig/shearing_$test &
    $CMD -invert_gamma -gravity_v "0 0" -o $fig/shearing_$test >/dev/null &
    wait
fi

wait
