#include <Core/Arrays/ARRAYS_ND.h>
#include <Core/Arrays/FACE_ARRAYS.h>
#include <Core/Geometry_Particles/DEBUG_PARTICLES.h>
#include <Core/Grids/CELL_ITERATOR.h>
#include <Core/Grids/FACE_ITERATOR.h>
#include <Core/Grids/GRID.h>
#include <Core/Interpolation/AVERAGING_UNIFORM.h>
#include <Core/Parsing/PARSE_ARGS.h>
#include <Core/Read_Write/FILE_UTILITIES.h>
#include <Core/Utilities/PROCESS_UTILITIES.h>
#include <Core/Utilities/VIEWER_DIR.h>
#include <Core/Viewer/VIEWER_OUTPUT.h>

using namespace PhysBAM;

typedef double T;
typedef VECTOR<T,2> TV;
typedef VECTOR<int,2> IV;

int main(int argc,char *argv[])
{
    PROCESS_UTILITIES::Set_Floating_Point_Exception_Handling(true);
    PROCESS_UTILITIES::Set_Backtrace(true);

    PARSE_ARGS parse_args(argc,argv);
    // LOG::Initialize_Logging(false,false,1<<30,true);
    LOG::cout<<parse_args.Print_Arguments()<<std::endl;
    LOG::cout<<std::setprecision(16);

    std::string input;
    int test_frame=0;
    parse_args.Add("-in",&input,"path","input directory");
    parse_args.Add("-frame",&test_frame,"int","frame to L2 test");
    parse_args.Parse(true);

    VIEWER_DIR vd_in(input);
    
    GRID<TV> grid;
    Read_From_File(vd_in.Common_File("grid"),grid);
    vd_in.Advance_Directory(0);

    ARRAY<T,IV> density;
    ARRAY<T,IV> pressure;
    // ARRAY<TV,IV> cell_velocities;
    ARRAY<T,FACE_INDEX<TV::m> > face_velocities;

    // int f=0;
    vd_in.frame_stack(0)=test_frame;
    vd_in.Update_Current_Directory();
    if(!vd_in.Valid_Frame(false)) vd_in.Read_Last_Frame(0);

    // for(;vd_in.Valid_Frame(true)&&(f<test_frame);f++)
    //     vd_in.Advance_Directory(0);

    // Read_From_File(vd_in.Frame_File("centered_velocities"),cell_velocities);
    Read_From_File(vd_in.Frame_File("velocities"),face_velocities);
    Read_From_File(vd_in.Frame_File("pressure"),pressure);

    AVERAGING_UNIFORM<TV> avg;
    
    T p_sum=0;
    T L2_cell=0;
    T Linf_cell=0;
    int count=0;
    for(CELL_ITERATOR<TV> it(grid);it.Valid();it.Next())
    {
        TV v_cell=avg.Face_To_Cell_Vector(grid,it.index,face_velocities);
        T local=v_cell.Magnitude();
        Linf_cell=max(Linf_cell,local);
        L2_cell+=sqr(local);
        p_sum+=pressure(it.index);
        count++;
    }
    L2_cell/=count;
    LOG::printf("Pressure sum for frame %P: %P\n",vd_in.frame_stack(0),p_sum);
    
    // T L2_face=0;
    // for(int i=0;i<face_velocities.array.m;i++)
    //     L2_face+=sqr(face_velocities.array(i));
    // L2_face/=face_velocities.array.m;
        
    // LOG::printf("L2 values for frame %P: \n \t cell: %P \n \t face: %P\n",vd_in.frame_stack(0),L2_cell,L2_face);
    LOG::printf("Values for frame %P:\n   L2: %P \n Linf: %P\n",vd_in.frame_stack(0),L2_cell,Linf_cell);
    
    // LOG::Finish_Logging();
    return 0;
}
